=== modified file 'bzrlib/errors.py'
--- bzrlib/errors.py	2007-01-19 09:47:38 +0000
+++ bzrlib/errors.py	2007-01-19 19:23:53 +0000
@@ -18,13 +18,17 @@
 """
 
 
-from bzrlib import (symbol_versioning,
-                    osutils,)
-from bzrlib.patches import (PatchSyntax, 
-                            PatchConflict, 
-                            MalformedPatchHeader,
-                            MalformedHunkHeader,
-                            MalformedLine,)
+from bzrlib import (
+    osutils,
+    symbol_versioning,
+    )
+from bzrlib.patches import (
+    MalformedHunkHeader,
+    MalformedLine,
+    MalformedPatchHeader,
+    PatchConflict,
+    PatchSyntax,
+    )
 
 
 # TODO: is there any value in providing the .args field used by standard
@@ -337,7 +341,7 @@
 class RenameFailedFilesExist(BzrError):
     """Used when renaming and both source and dest exist."""
 
-    _fmt = ("Could not rename %(source)s to %(dest)s because both files exist."
+    _fmt = ("Could not rename %(source)s => %(dest)s because both files exist."
          "%(extra)s")
 
     def __init__(self, source, dest, extra=None):

=== modified file 'bzrlib/tests/blackbox/test_mv.py'
--- bzrlib/tests/blackbox/test_mv.py	2007-01-19 09:47:38 +0000
+++ bzrlib/tests/blackbox/test_mv.py	2007-01-19 19:23:53 +0000
@@ -165,7 +165,6 @@
         is handled correctly by bzr mv.
         Setup: a is in the working tree, b does not exist.
         User does: mv a b; bzr mv a b
-
         """
         self.build_tree(['a'])
         tree = self.make_branch_and_tree('.')
@@ -182,7 +181,6 @@
         to another versiond file will fail.
         Setup: a and b are in the working tree.
         User does: rm b; mv a b; bzr mv a b
-
         """
         self.build_tree(['a', 'b'])
         tree = self.make_branch_and_tree('.')
@@ -204,7 +202,6 @@
         directory by an external tool, is handled correctly by bzr mv.
         Setup: a and sub/ are in the working tree.
         User does: mv a sub/a; bzr mv a sub/a
-
         """
         self.build_tree(['a', 'sub/'])
         tree = self.make_branch_and_tree('.')
@@ -221,7 +218,6 @@
         into an unversioned directory will fail.
         Setup: a is in the working tree, sub/ is not.
         User does: mv a sub/a; bzr mv a sub/a
-
         """
         self.build_tree(['a', 'sub/'])
         tree = self.make_branch_and_tree('.')
@@ -241,7 +237,6 @@
         directory by an external tool, is handled correctly by bzr mv.
         Setup: a1, a2, sub are in the working tree.
         User does: mv a1 sub/.; bzr mv a1 a2 sub
-
         """
         self.build_tree(['a1', 'a2', 'sub/'])
         tree = self.make_branch_and_tree('.')
@@ -259,7 +254,6 @@
         into an unversioned directory will fail.
         Setup: a1, a2 are in the working tree, sub is not.
         User does: mv a1 sub/.; bzr mv a1 a2 sub
-
         """
         self.build_tree(['a1', 'a2', 'sub/'])
         tree = self.make_branch_and_tree('.')
@@ -282,7 +276,6 @@
         option to force this.
         Setup: a is in the working tree, b not versioned.
         User does: mv a b; touch a; bzr mv a b
-
         """
         self.build_tree(['a', 'b'])
         tree = self.make_branch_and_tree('.')
@@ -291,7 +284,7 @@
         os.rename('a', 'b')
         self.build_tree(['a']) #touch a
         self.run_bzr_error(
-            ["^bzr: ERROR: Could not rename a to b because both files exist."
+            ["^bzr: ERROR: Could not rename a => b because both files exist."
              " \(Use --after to update the Bazaar id\)$"],
             'mv', 'a', 'b')
         self.failUnlessExists('a')
@@ -307,7 +300,6 @@
         Setup: a is in the working tree and b exists.
         User does: mv a b; touch a; bzr mv a b --after
         Resulting in a => b and a is unknown.
-
         """
         self.build_tree(['a', 'b'])
         tree = self.make_branch_and_tree('.')
@@ -331,7 +323,6 @@
         Setup: a1, a2, sub are versioned and in the working tree,
                sub/a1, sub/a2 are in working tree.
         User does: mv a* sub; touch a1; touch a2; bzr mv a1 a2 sub
-
         """
         self.build_tree(['a1', 'a2', 'sub/', 'sub/a1', 'sub/a2'])
         tree = self.make_branch_and_tree('.')
@@ -342,7 +333,7 @@
         self.build_tree(['a2']) #touch a2
 
         self.run_bzr_error(
-            ["^bzr: ERROR: Could not rename a1 to sub/a1 because both files exist."
+            ["^bzr: ERROR: Could not rename a1 => sub/a1 because both files exist."
              " \(Use --after to update the Bazaar id\)$"],
             'mv', 'a1', 'a2', 'sub')
         self.failUnlessExists('a1')
@@ -362,7 +353,6 @@
         Setup: a1, a2, sub are versioned and in the working tree,
                sub/a1, sub/a2 are in working tree.
         User does: mv a* sub; touch a1; touch a2; bzr mv a1 a2 sub --after
-
         """
         self.build_tree(['a1', 'a2', 'sub/', 'sub/a1', 'sub/a2'])
         tree = self.make_branch_and_tree('.')

=== modified file 'bzrlib/workingtree.py'
--- bzrlib/workingtree.py	2007-01-19 09:47:38 +0000
+++ bzrlib/workingtree.py	2007-01-19 19:23:53 +0000
@@ -72,7 +72,6 @@
 
 from bzrlib import symbol_versioning
 from bzrlib.decorators import needs_read_lock, needs_write_lock
-
 from bzrlib.inventory import InventoryEntry, Inventory, ROOT_ID
 from bzrlib.lockable_files import LockableFiles, TransportLock
 from bzrlib.lockdir import LockDir
@@ -1147,47 +1146,41 @@
         for entry in rename_entries:
             try:
                 self._move_entry(entry)
-            except OSError, e:
-                self._rollback_move(moved)
-                raise errors.BzrRenameFailedError(entry.from_rel, entry.to_rel,
-                    e[1])
-            except errors.BzrError, e:
+            except:
                 self._rollback_move(moved)
                 raise
             moved.append(entry)
 
     def _rollback_move(self, moved):
-        """Try to rollback a previous move in case of an error in the
-        filesystem.
-        """
+        """Try to rollback a previous move in case of an filesystem error."""
         inv = self.inventory
         for entry in moved:
             try:
-                self._move_entry(entry, inverse=True)
+                self._move_entry(_RenameEntry(entry.to_rel, entry.from_id,
+                    entry.to_tail, entry.to_parent_id, entry.from_rel,
+                    entry.from_tail, entry.from_parent_id,
+                    entry.only_change_inv))
             except OSError, e:
-                raise errors.BzrMoveFailedError( '', '',
-                    errors.BzrError("Rollback failed."
+                raise errors.BzrMoveFailedError( '', '', "Rollback failed."
                         " The working tree is in an inconsistent state."
                         " Please consider doing a 'bzr revert'."
-                        " Error message is: %s" % e[1]))
+                        " Error message is: %s" % e[1])
 
-    def _move_entry(self, entry, inverse=False):
+    def _move_entry(self, entry):
         inv = self.inventory
         from_rel_abs = self.abspath(entry.from_rel)
         to_rel_abs = self.abspath(entry.to_rel)
-
         if from_rel_abs == to_rel_abs:
-            raise errors.BzrMoveFailedError(from_rel, to_rel,
+            raise errors.BzrMoveFailedError(entry.from_rel, entry.to_rel,
                 "Source and target are identical.")
 
-        if inverse:
-            if not entry.only_change_inv:
-                osutils.rename(to_rel_abs, from_rel_abs)
-            inv.rename(entry.from_id, entry.from_parent_id, entry.from_tail)
-        else:
-            if not entry.only_change_inv:
+        if not entry.only_change_inv:
+            try:
                 osutils.rename(from_rel_abs, to_rel_abs)
-            inv.rename(entry.from_id, entry.to_parent_id, entry.to_tail)
+            except OSError, e:
+                raise errors.BzrMoveFailedError(entry.from_rel,
+                    entry.to_rel, e[1])
+        inv.rename(entry.from_id, entry.to_parent_id, entry.to_tail)
 
     @needs_tree_write_lock
     def rename_one(self, from_rel, to_rel, after=False):
@@ -1257,7 +1250,7 @@
 
     class _RenameEntry(object):
         def __init__(self, from_rel, from_id, from_tail, from_parent_id,
-                     to_rel, to_tail, to_parent_id):
+                     to_rel, to_tail, to_parent_id, only_change_inv=False):
             self.from_rel = from_rel
             self.from_id = from_id
             self.from_tail = from_tail
@@ -1265,7 +1258,7 @@
             self.to_rel = to_rel
             self.to_tail = to_tail
             self.to_parent_id = to_parent_id
-            self.only_change_inv = False
+            self.only_change_inv = only_change_inv
 
     @needs_read_lock
     def unknowns(self):

